function Pulse = DSSSPulse( Seq, fsTc )
% DSSSPulse - DS/SS pulse from spreading sequence
%
% Generate a pulse for linear DS/SS modulation from a spreading sequence.
%
% Inputs:
%   Seq  - spreading sequence
%   fsTc - number of samples per chip
%
% Output:
%   Pulse - spread spectrum pulse
%
% Example:
%   Pulse = DSSSPulse( Seq, fsTc )

%% generate pulse via function LinearModulation
Pulse = LinearModulation( Seq, RectPulse(fsTc), fsTc );